Array

Struct Array 

pub struct Array;
Placeholder type for array SFields.

Array types in XRPL (like Signers, Memos, etc.) cannot be directly retrieved as complete values. Instead, they are used within Location to navigate to specific array elements.

This type implements FieldGetter as a no-op to satisfy the trait bound, but should not be used to actually retrieve values.