Object

Struct Object 

pub struct Object;
Placeholder type for object SFields.

Object types in XRPL (like Memo, SignerEntry, etc.) cannot be directly retrieved as complete values. Instead, they are used within Location to navigate to specific object fields.

This type implements FieldGetter as a no-op to satisfy the trait bound, but should not be used to actually retrieve values.